"""
    Audit API reference

    Service name    # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

import nulltype  # noqa: F401

from pensando_ent.psm.model_utils import (  # noqa: F401
    ApiTypeError,
    ModelComposed,
    ModelNormal,
    ModelSimple,
    cached_property,
    change_keys_js_to_python,
    convert_js_args_to_python_args,
    date,
    datetime,
    file_type,
    none_type,
    validate_get_composed_info,
)

def lazy_import():
    from pensando_ent.psm.model.api_object_ref import ApiObjectRef
    globals()['ApiObjectRef'] = ApiObjectRef


class AuditEventAttributes(ModelNormal):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    Attributes:
      allowed_values (dict): The key is the tuple path to the attribute
          and the for var_name this is (var_name,). The value is a dict
          with a capitalized key describing the allowed value and an allowed
          value. These dicts store the allowed enum values.
      attribute_map (dict): The key is attribute name
          and the value is json key in definition.
      discriminator_value_class_map (dict): A dict to go from the discriminator
          variable value to the discriminator class name.
      validations (dict): The key is the tuple path to the attribute
          and the for var_name this is (var_name,). The value is a dict
          that stores validations for max_length, min_length, max_items,
          min_items, exclusive_maximum, inclusive_maximum, exclusive_minimum,
          inclusive_minimum, and regex.
      additional_properties_type (tuple): A tuple of classes accepted
          as additional properties values.
    """

    allowed_values = {
        ('level',): {
            'BASIC': "basic",
            'REQUEST': "request",
            'RESPONSE': "response",
            'REQUEST-RESPONSE': "request-response",
        },
        ('outcome',): {
            'SUCCESS': "success",
            'FAILURE': "failure",
        },
        ('stage',): {
            'REQUESTAUTHORIZATION': "requestauthorization",
            'REQUESTPROCESSING': "requestprocessing",
        },
    }

    validations = {
        ('external_id',): {
            'max_length': 64,
            'regex': {
                'pattern': r'^[a-zA-Z0-9\-]+$',  # noqa: E501
            },
        },
    }

    additional_properties_type = None

    _nullable = False

    @cached_property
    def openapi_types():
        """
        This must be a method because a model may have properties that are
        of type self, this must run after the class is loaded

        Returns
            openapi_types (dict): The key is attribute name
                and the value is attribute type.
        """
        lazy_import()
        return {
            'action': (str,),  # noqa: E501
            'client_ips': ([str],),  # noqa: E501
            'data': ({str: (str,)},),  # noqa: E501
            'external_id': (str,),  # noqa: E501
            'gateway_ip': (str,),  # noqa: E501
            'gateway_node': (str,),  # noqa: E501
            'level': (str,),  # noqa: E501
            'outcome': (str,),  # noqa: E501
            'request_object': (str,),  # noqa: E501
            'request_uri': (str,),  # noqa: E501
            'resource': (ApiObjectRef,),  # noqa: E501
            'response_object': (str,),  # noqa: E501
            'service_name': (str,),  # noqa: E501
            'stage': (str,),  # noqa: E501
            'user': (ApiObjectRef,),  # noqa: E501
        }

    @cached_property
    def discriminator():
        return None


    attribute_map = {
        'action': 'action',  # noqa: E501
        'client_ips': 'client-ips',  # noqa: E501
        'data': 'data',  # noqa: E501
        'external_id': 'external-id',  # noqa: E501
        'gateway_ip': 'gateway-ip',  # noqa: E501
        'gateway_node': 'gateway-node',  # noqa: E501
        'level': 'level',  # noqa: E501
        'outcome': 'outcome',  # noqa: E501
        'request_object': 'request-object',  # noqa: E501
        'request_uri': 'request-uri',  # noqa: E501
        'resource': 'resource',  # noqa: E501
        'response_object': 'response-object',  # noqa: E501
        'service_name': 'service-name',  # noqa: E501
        'stage': 'stage',  # noqa: E501
        'user': 'user',  # noqa: E501
    }

    _composed_schemas = {}

    required_properties = set([
        '_data_store',
        '_check_type',
        '_spec_property_naming',
        '_path_to_item',
        '_configuration',
        '_visited_composed_classes',
    ])

    @convert_js_args_to_python_args
    def __init__(self, *args, **kwargs):  # noqa: E501
        """AuditEventAttributes - a model defined in OpenAPI

        Keyword Args:
            _check_type (bool): if True, values for parameters in openapi_types
                                will be type checked and a TypeError will be
                                raised if the wrong type is input.
                                Defaults to True
            _path_to_item (tuple/list): This is a list of keys or values to
                                drill down to the model in received_data
                                when deserializing a response
            _spec_property_naming (bool): True if the variable names in the input data
                                are serialized names, as specified in the OpenAPI document.
                                False if the variable names in the input data
                                are pythonic names, e.g. snake case (default)
            _configuration (Configuration): the instance to use when
                                deserializing a file_type parameter.
                                If passed, type conversion is attempted
                                If omitted no type conversion is done.
            _visited_composed_classes (tuple): This stores a tuple of
                                classes that we have traveled through so that
                                if we see that class again we will not use its
                                discriminator again.
                                When traveling through a discriminator, the
                                composed schema that is
                                is traveled through is added to this set.
                                For example if Animal has a discriminator
                                petType and we pass in "Dog", and the class Dog
                                allOf includes Animal, we move through Animal
                                once using the discriminator, and pick Dog.
                                Then in Dog, we will make an instance of the
                                Animal class but this time we won't travel
                                through its discriminator because we passed in
                                _visited_composed_classes = (Animal,)
            action (str): Action that was requested/performed on the referred object. For non API server resources, it is the http method.. [optional]  # noqa: E501
            client_ips ([str]): IP addresses of client and intermediate proxies from where API request was made.. [optional]  # noqa: E501
            data ({str: (str,)}): Data is unstructured key value map stored with audit log that may be set by hooks in API Gateway. We can store Signature in JWS compact serialization format in this map. Data in this map will not be signed.. [optional]  # noqa: E501
            external_id (str): ID passed in by an external application to link audit event to the request. It should be AlphaNumeric and can contain -. Maximum length supported is 64. Length of string should be between 0 and 64. Must be alpha numeric and can have -.. [optional]  # noqa: E501
            gateway_ip (str): IP address of API Gateway where action was observed.. [optional]  # noqa: E501
            gateway_node (str): Name of the venice node where action was observed.. [optional]  # noqa: E501
            level (str): Level to control amount of audit information logged.. [optional] if omitted the server will use the default value of "basic"  # noqa: E501
            outcome (str): Outcome represents the outcome of action on resource.. [optional] if omitted the server will use the default value of "success"  # noqa: E501
            request_object (str): Object from the request in JSON format.. [optional]  # noqa: E501
            request_uri (str): RequestURI is the request URI as sent by the client. Should be a valid URI.. [optional]  # noqa: E501
            resource (ApiObjectRef): [optional]  # noqa: E501
            response_object (str): Object from the response in JSON format to be sent to the client.. [optional]  # noqa: E501
            service_name (str): Name of service that handled the request and performed the requested operation for ex: search, events etc.. [optional]  # noqa: E501
            stage (str): Request handling stage at which audit log was generated.. [optional] if omitted the server will use the default value of "requestauthorization"  # noqa: E501
            user (ApiObjectRef): [optional]  # noqa: E501
        """

        _check_type = kwargs.pop('_check_type', True)
        _spec_property_naming = kwargs.pop('_spec_property_naming', False)
        _path_to_item = kwargs.pop('_path_to_item', ())
        _configuration = kwargs.pop('_configuration', None)
        _visited_composed_classes = kwargs.pop('_visited_composed_classes', ())

        if args:
            raise ApiTypeError(
                "Invalid positional arguments=%s passed to %s. Remove those invalid positional arguments." % (
                    args,
                    self.__class__.__name__,
                ),
                path_to_item=_path_to_item,
                valid_classes=(self.__class__,),
            )

        self._data_store = {}
        self._check_type = _check_type
        self._spec_property_naming = _spec_property_naming
        self._path_to_item = _path_to_item
        self._configuration = _configuration
        self._visited_composed_classes = _visited_composed_classes + (self.__class__,)

        for var_name, var_value in kwargs.items():
            if var_name not in self.attribute_map and \
                        self._configuration is not None and \
                        self._configuration.discard_unknown_keys and \
                        self.additional_properties_type is None:
                # discard variable.
                continue
            setattr(self, var_name, var_value)



"""
    Security API reference

       # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import psm
from pensando_ent.psm.model.api_list_meta import ApiListMeta
from pensando_ent.psm.model.security_ip_sec_policy import SecurityIPSecPolicy
globals()['ApiListMeta'] = ApiListMeta
globals()['SecurityIPSecPolicy'] = SecurityIPSecPolicy
from pensando_ent.psm.psm.model.security_ip_sec_policy_list import SecurityIPSecPolicyList


class TestSecurityIPSecPolicyList(unittest.TestCase):
    """SecurityIPSecPolicyList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testSecurityIPSecPolicyList(self):
        """Test SecurityIPSecPolicyList"""
        # FIXME: construct object with mandatory attributes with example values
        # model = SecurityIPSecPolicyList()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



# flake8: noqa

# import all models into this package
# if you have many models here with many references from one model to another this may
# raise a RecursionError
# to avoid this, import only the models that you directly need like:
# from from psm.model.pet import Pet
# or import this package, but before doing it, use:
# import sys
# sys.setrecursionlimit(n)

from pensando_ent.psm.model.api_agg_watch_options import ApiAggWatchOptions
from pensando_ent.psm.model.api_bgp_asn import ApiBgpAsn
from pensando_ent.psm.model.api_kind_watch_options import ApiKindWatchOptions
from pensando_ent.psm.model.api_list_meta import ApiListMeta
from pensando_ent.psm.model.api_list_watch_options import ApiListWatchOptions
from pensando_ent.psm.model.api_object_meta import ApiObjectMeta
from pensando_ent.psm.model.api_object_ref import ApiObjectRef
from pensando_ent.psm.model.api_status import ApiStatus
from pensando_ent.psm.model.api_status_result import ApiStatusResult
from pensando_ent.psm.model.api_timestamp import ApiTimestamp
from pensando_ent.psm.model.api_type_meta import ApiTypeMeta
from pensando_ent.psm.model.api_watch_control import ApiWatchControl
from pensando_ent.psm.model.api_watch_event import ApiWatchEvent
from pensando_ent.psm.model.api_watch_event_list import ApiWatchEventList
from pensando_ent.psm.model.evpn_route_evpn_type2_route import EVPNRouteEVPNType2Route
from pensando_ent.psm.model.evpn_route_evpn_type5_route import EVPNRouteEVPNType5Route
from pensando_ent.psm.model.googleprotobuf_any import GoogleprotobufAny
from pensando_ent.psm.model.health_status_peering_status import HealthStatusPeeringStatus
from pensando_ent.psm.model.network_bgp_neighbor import NetworkBGPNeighbor
from pensando_ent.psm.model.routing_evpn_route import RoutingEVPNRoute
from pensando_ent.psm.model.routing_empty_req import RoutingEmptyReq
from pensando_ent.psm.model.routing_health import RoutingHealth
from pensando_ent.psm.model.routing_health_status import RoutingHealthStatus
from pensando_ent.psm.model.routing_neighbor import RoutingNeighbor
from pensando_ent.psm.model.routing_neighbor_filter import RoutingNeighborFilter
from pensando_ent.psm.model.routing_neighbor_list import RoutingNeighborList
from pensando_ent.psm.model.routing_neighbor_status import RoutingNeighborStatus
from pensando_ent.psm.model.routing_route import RoutingRoute
from pensando_ent.psm.model.routing_route_filter import RoutingRouteFilter
from pensando_ent.psm.model.routing_route_list import RoutingRouteList
from pensando_ent.psm.model.routing_route_status import RoutingRouteStatus



"""
    Network API reference

       # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import psm
from pensando_ent.psm.model.network_auto_msg_lb_policy_watch_helper_watch_event import NetworkAutoMsgLbPolicyWatchHelperWatchEvent
globals()['NetworkAutoMsgLbPolicyWatchHelperWatchEvent'] = NetworkAutoMsgLbPolicyWatchHelperWatchEvent
from pensando_ent.psm.psm.model.network_auto_msg_lb_policy_watch_helper import NetworkAutoMsgLbPolicyWatchHelper


class TestNetworkAutoMsgLbPolicyWatchHelper(unittest.TestCase):
    """NetworkAutoMsgLbPolicyWatchHelper unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testNetworkAutoMsgLbPolicyWatchHelper(self):
        """Test NetworkAutoMsgLbPolicyWatchHelper"""
        # FIXME: construct object with mandatory attributes with example values
        # model = NetworkAutoMsgLbPolicyWatchHelper()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Aggwatch API reference

       # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import psm
from pensando_ent.psm.model.api_object_ref import ApiObjectRef
from pensando_ent.psm.model.api_status_result import ApiStatusResult
globals()['ApiObjectRef'] = ApiObjectRef
globals()['ApiStatusResult'] = ApiStatusResult
from pensando_ent.psm.psm.model.api_status import ApiStatus


class TestApiStatus(unittest.TestCase):
    """ApiStatus unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testApiStatus(self):
        """Test ApiStatus"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ApiStatus()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Security API reference

       # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import psm
from pensando_ent.psm.model.security_ip_sec_config import SecurityIPSecConfig
from pensando_ent.psm.model.security_ip_sec_policy_rule import SecurityIPSecPolicyRule
globals()['SecurityIPSecConfig'] = SecurityIPSecConfig
globals()['SecurityIPSecPolicyRule'] = SecurityIPSecPolicyRule
from pensando_ent.psm.psm.model.security_ip_sec_policy_spec import SecurityIPSecPolicySpec


class TestSecurityIPSecPolicySpec(unittest.TestCase):
    """SecurityIPSecPolicySpec unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testSecurityIPSecPolicySpec(self):
        """Test SecurityIPSecPolicySpec"""
        # FIXME: construct object with mandatory attributes with example values
        # model = SecurityIPSecPolicySpec()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Security API reference

       # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import psm
from pensando_ent.psm.model.security_alg import SecurityALG
from pensando_ent.psm.model.security_proto_port import SecurityProtoPort
globals()['SecurityALG'] = SecurityALG
globals()['SecurityProtoPort'] = SecurityProtoPort
from pensando_ent.psm.psm.model.security_app_spec import SecurityAppSpec


class TestSecurityAppSpec(unittest.TestCase):
    """SecurityAppSpec unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testSecurityAppSpec(self):
        """Test SecurityAppSpec"""
        # FIXME: construct object with mandatory attributes with example values
        # model = SecurityAppSpec()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Network API reference

       # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import psm
from pensando_ent.psm.model.network_route_distinguisher import NetworkRouteDistinguisher
from pensando_ent.psm.model.security_propagation_status import SecurityPropagationStatus
globals()['NetworkRouteDistinguisher'] = NetworkRouteDistinguisher
globals()['SecurityPropagationStatus'] = SecurityPropagationStatus
from pensando_ent.psm.psm.model.network_virtual_router_status import NetworkVirtualRouterStatus


class TestNetworkVirtualRouterStatus(unittest.TestCase):
    """NetworkVirtualRouterStatus unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testNetworkVirtualRouterStatus(self):
        """Test NetworkVirtualRouterStatus"""
        # FIXME: construct object with mandatory attributes with example values
        # model = NetworkVirtualRouterStatus()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Workload API reference

    Service name    # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import psm
from pensando_ent.psm.model.api_object_meta import ApiObjectMeta
from pensando_ent.psm.model.workload_endpoint_spec import WorkloadEndpointSpec
from pensando_ent.psm.model.workload_endpoint_status import WorkloadEndpointStatus
globals()['ApiObjectMeta'] = ApiObjectMeta
globals()['WorkloadEndpointSpec'] = WorkloadEndpointSpec
globals()['WorkloadEndpointStatus'] = WorkloadEndpointStatus
from pensando_ent.psm.psm.model.workload_endpoint import WorkloadEndpoint


class TestWorkloadEndpoint(unittest.TestCase):
    """WorkloadEndpoint unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testWorkloadEndpoint(self):
        """Test WorkloadEndpoint"""
        # FIXME: construct object with mandatory attributes with example values
        # model = WorkloadEndpoint()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



# flake8: noqa

# import all models into this package
# if you have many models here with many references from one model to another this may
# raise a RecursionError
# to avoid this, import only the models that you directly need like:
# from from psm.model.pet import Pet
# or import this package, but before doing it, use:
# import sys
# sys.setrecursionlimit(n)

from pensando_ent.psm.model.api_agg_watch_options import ApiAggWatchOptions
from pensando_ent.psm.model.api_kind_watch_options import ApiKindWatchOptions
from pensando_ent.psm.model.api_label import ApiLabel
from pensando_ent.psm.model.api_list_meta import ApiListMeta
from pensando_ent.psm.model.api_list_watch_options import ApiListWatchOptions
from pensando_ent.psm.model.api_object_meta import ApiObjectMeta
from pensando_ent.psm.model.api_object_ref import ApiObjectRef
from pensando_ent.psm.model.api_status import ApiStatus
from pensando_ent.psm.model.api_status_result import ApiStatusResult
from pensando_ent.psm.model.api_timestamp import ApiTimestamp
from pensando_ent.psm.model.api_type_meta import ApiTypeMeta
from pensando_ent.psm.model.api_watch_control import ApiWatchControl
from pensando_ent.psm.model.api_watch_event import ApiWatchEvent
from pensando_ent.psm.model.api_watch_event_list import ApiWatchEventList
from pensando_ent.psm.model.googleprotobuf_any import GoogleprotobufAny
from pensando_ent.psm.model.labels_requirement import LabelsRequirement
from pensando_ent.psm.model.labels_selector import LabelsSelector
from pensando_ent.psm.model.rollout_auto_msg_rollout_action_watch_helper import RolloutAutoMsgRolloutActionWatchHelper
from pensando_ent.psm.model.rollout_auto_msg_rollout_action_watch_helper_watch_event import RolloutAutoMsgRolloutActionWatchHelperWatchEvent
from pensando_ent.psm.model.rollout_auto_msg_rollout_watch_helper import RolloutAutoMsgRolloutWatchHelper
from pensando_ent.psm.model.rollout_auto_msg_rollout_watch_helper_watch_event import RolloutAutoMsgRolloutWatchHelperWatchEvent
from pensando_ent.psm.model.rollout_rollout import RolloutRollout
from pensando_ent.psm.model.rollout_rollout_action import RolloutRolloutAction
from pensando_ent.psm.model.rollout_rollout_action_list import RolloutRolloutActionList
from pensando_ent.psm.model.rollout_rollout_action_status import RolloutRolloutActionStatus
from pensando_ent.psm.model.rollout_rollout_list import RolloutRolloutList
from pensando_ent.psm.model.rollout_rollout_phase import RolloutRolloutPhase
from pensando_ent.psm.model.rollout_rollout_spec import RolloutRolloutSpec
from pensando_ent.psm.model.rollout_rollout_status import RolloutRolloutStatus



"""
    Events API reference

    Service name    # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import psm
from pensando_ent.psm.psm.model.events_get_event_request import EventsGetEventRequest


class TestEventsGetEventRequest(unittest.TestCase):
    """EventsGetEventRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testEventsGetEventRequest(self):
        """Test EventsGetEventRequest"""
        # FIXME: construct object with mandatory attributes with example values
        # model = EventsGetEventRequest()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Network API reference

       # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import psm
from pensando_ent.psm.model.network_virtual_router_peering_group import NetworkVirtualRouterPeeringGroup
globals()['NetworkVirtualRouterPeeringGroup'] = NetworkVirtualRouterPeeringGroup
from pensando_ent.psm.psm.model.network_auto_msg_virtual_router_peering_group_watch_helper_watch_event import NetworkAutoMsgVirtualRouterPeeringGroupWatchHelperWatchEvent


class TestNetworkAutoMsgVirtualRouterPeeringGroupWatchHelperWatchEvent(unittest.TestCase):
    """NetworkAutoMsgVirtualRouterPeeringGroupWatchHelperWatchEvent unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testNetworkAutoMsgVirtualRouterPeeringGroupWatchHelperWatchEvent(self):
        """Test NetworkAutoMsgVirtualRouterPeeringGroupWatchHelperWatchEvent"""
        # FIXME: construct object with mandatory attributes with example values
        # model = NetworkAutoMsgVirtualRouterPeeringGroupWatchHelperWatchEvent()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Cluster API reference

    Service name    # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import psm
from pensando_ent.psm.model.api_object_meta import ApiObjectMeta
from pensando_ent.psm.model.cluster_node_spec import ClusterNodeSpec
from pensando_ent.psm.model.cluster_node_status import ClusterNodeStatus
globals()['ApiObjectMeta'] = ApiObjectMeta
globals()['ClusterNodeSpec'] = ClusterNodeSpec
globals()['ClusterNodeStatus'] = ClusterNodeStatus
from pensando_ent.psm.psm.model.cluster_node import ClusterNode


class TestClusterNode(unittest.TestCase):
    """ClusterNode unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testClusterNode(self):
        """Test ClusterNode"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ClusterNode()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
